==> vs-essential-plugins-0.0.3.tgz: package/README.md <==

<center><img src="https://pbs.twimg.com/profile_images/922911523328081920/jEKFRPKV_400x400.jpg" /></center>

# Visual Studio Code - Essential Plugins

[VS Code](https://code.visualstudio.com/) is a new type of tool that combines the simplicity of a code editor with what developers need for their core edit-build-debug cycle. Code provides comprehensive editing and debugging support, an extensibility model, and lightweight integration with existing tools.

This library enhances usability by providing prepackaged essential plugins for visual studio code. Before we dive into on how to use this library. We would like to thank all the contributor of plugins we have configured in this library

> **Note:** These prepacked plugins will definitely help developers of [React](https://github.com/facebook/react) & [ReactNative](https://github.com/facebook/react-native) community



## Usage

`npm install vs-essential-plugins --save`

`npm install`

On `install` it will automatically install all plugins configured in library

> **Note:**
> - If you are using MAC then please make your that you have install `code` command in PATH. Please refer [Microsoft Blog](https://code.visualstudio.com/docs/setup/mac#_launching-from-the-command-line) for more details
> - All plugins are defined in package.json `postinstall` section

# Essential Plugins
- [svetlozarangelov.vscode-open-project](https://marketplace.visualstudio.com/items?itemName=svetlozarangelov.vscode-open-project): _This extension allows you to easily switch projects inside Visual Studio Code_
- [DavidAnson.vscode-markdownlint](https://marketplace.visualstudio.com/items?itemName=DavidAnson.vscode-markdownlint): _Markdown/CommonMark linting and style checking for Visual Studio Code_
- [dbaeumer.vscode-eslint](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint): _The extension uses the ESLint library installed in the opened workspace folder_
- [vsmobile.vscode-react-native](https://marketplace.visualstudio.com/items?itemName=vsmobile.vscode-react-native): _This extension provides a development environment for React Native projects. Using this extension, you can debug your code, quickly run react-native commands from the command palette, and use IntelliSense to browse objects, functions and parameters for React Native APIs_
- [flowtype.flow-for-vscode](https://marketplace.visualstudio.com/items?itemName=flowtype.flow-for-vscode): _This extension adds Flow support for VS Code. Flow is a static type checker, designed to find type errors in JavaScript programs_
- [gcazaciuc.vscode-flow-ide](https://marketplace.visualstudio.com/items?itemName=gcazaciuc.vscode-flow-ide): _An alternative Flowtype extension for Visual Studio Code. Flowtype is a static type checker ment to find errors in Javascript programs_
- [streetsidesoftware.code-spell-checker](https://marketplace.visualstudio.com/items?itemName=streetsidesoftware.code-spell-checker): _A basic spell checker that works well with camelCase code_
- [ms-vscode.atom-keybindings](https://marketplace.visualstudio.com/items?itemName=ms-vscode.atom-keybindings): _This extension ports popular Atom keyboard shortcuts to Visual Studio Code. After installing the extension and restarting VS Code your favorite keyboard shortcuts from Atom are now available_
- [robertohuertasm.vscode-icons](https://marketplace.visualstudio.com/items?itemName=robertohuertasm.vscode-icons): _Bring icons to your Visual Studio Code_
- [naumovs.color-highlight](https://marketplace.visualstudio.com/items?itemName=naumovs.color-highlight): _This extension styles css/web colors found in your document_
- [2gua.rainbow-brackets](https://marketplace.visualstudio.com/items?itemName=2gua.rainbow-brackets): _Provide rainbow colors for the round brackets, the square brackets and the squiggly brackets. This is particularly useful for Lisp or Clojure programmers, and of course, JavaScript, and other programmers_
- [wayou.vscode-todo-highlight](https://marketplace.visualstudio.com/items?itemName=wayou.vscode-todo-highlight): _Highlight TODO,FIXME or any annotations within your code_
- [SirTori.indenticator](https://marketplace.visualstudio.com/items?itemName=SirTori.indenticator): _Visually highlights the current indent depth_
- [cssho.vscode-svgviewer](https://marketplace.visualstudio.com/items?itemName=cssho.vscode-svgviewer): _SVG Viewer for Visual Studio Code Visual Studio Marketplace_
- [formulahendry.auto-close-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-close-tag): _Automatically add HTML/XML close tag, same as Visual Studio IDE or Sublime Text does_
- [formulahendry.auto-rename-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-rename-tag): _Automatically rename paired HTML/XML tag, same as Visual Studio IDE does_
- [formulahendry.auto-complete-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-complete-tag): _Combine the functions of Auto Close Tag and Auto Rename Tag_
- [christian-kohler.path-intellisense](https://marketplace.visualstudio.com/items?itemName=christian-kohler.path-intellisense): _Visual Studio Code plugin that autocompletes filenames_
- [EQuimper.react-native-react-redux](https://marketplace.visualstudio.com/items?itemName=EQuimper.react-native-react-redux): _React-Native/React/Redux snippets for es6/es7_
- [alexdima.copy-relative-path](https://marketplace.visualstudio.com/items?itemName=alexdima.copy-relative-path): _Copy Relative Path_
- [DotJoshJohnson.xml](https://marketplace.visualstudio.com/items?itemName=DotJoshJohnson.xml): _XML Tools for Visual Studio Code_
- [formulahendry.code-runner](https://marketplace.visualstudio.com/items?itemName=formulahendry.code-runner): _Run code snippet or code file for multiple languages: C, C++, Java, JavaScript, PHP, Python, Perl, Ruby, Go, Lua, Groovy, PowerShell, BAT/CMD, BASH/SH, F# Script, F# (.NET Core), C# Script, C# (.NET Core), VBScript, TypeScript, CoffeeScript, Scala, Swift, Julia, Crystal, OCaml Script, R, AppleScript, Elixir, Visual Basic .NET, Clojure, Haxe, Objective-C, Rust, Racket, AutoHotkey, AutoIt, Kotlin, Dart, Free Pascal, Haskell, Nim, D, and custom command_
- [joelday.docthis](https://marketplace.visualstudio.com/items?itemName=joelday.docthis): _"Document This" is a Visual Studio Code extension that automatically generates detailed JSDoc comments for both TypeScript and JavaScript files_
- [waderyan.gitblame](https://marketplace.visualstudio.com/items?itemName=waderyan.gitblame): _See Git Blame information in the status bar for the currently selected line_
- [eamodio.gitlens](https://marketplace.visualstudio.com/items?itemName=eamodio.gitlens): _GitLens supercharges the built-in Visual Studio Code Git capabilities. It helps you to visualize code authorship at a glance via Git blame annotations and code lens, seamlessly navigate and explore the history of a file or branch, gain valuable insights via powerful comparison commands, and so much more_
- [xyz.local-history](https://marketplace.visualstudio.com/items?itemName=xyz.local-history): _A visual source code plugin for maintaining local history of files_
- [esbenp.prettier-vscode](https://marketplace.visualstudio.com/items?itemName=esbenp.prettier-vscode): _Prettier formatter for Visual Studio Code_
- [Orta.vscode-react-native-storybooks](https://marketplace.visualstudio.com/items?itemName=Orta.vscode-react-native-storybooks): _Select storybooks inside your editor_
- [IBM.output-colorizer](https://marketplace.visualstudio.com/items?itemName=IBM.output-colorizer): _Language extension for VSCode/Bluemix Code that adds syntax colorization for both the output/debug/extensions panel and *.log files_
- [qezhu.gitlink](https://marketplace.visualstudio.com/items?itemName=qezhu.gitlink): _Inspired by GitHub extension for Visual Studio, this extension provide the feature that Go To current file's online link in browser and Copy the link in clipboard_


# Contributions
If you feel any X plugin should be part of these prepacked essential plugins, please feel free to raise a PR for the same. Any type of contribution will be very much appreciated

# License
Copyright @2017 Pranav Raj Singh Chauhan

vs-essential-plugins is provided under the MIT License.

==> vs-essential-plugins-0.0.4.tgz: package/README.md <==
<h1 align="center">

<p align="center"><img src="https://pbs.twimg.com/profile_images/922911523328081920/jEKFRPKV_400x400.jpg" width="300" height="300" /></p>

<p align="center">
  <a href="https://www.npmjs.com/package/vs-essential-plugins"><img src="http://img.shields.io/npm/v/vs-essential-plugins.svg?style=flat" /></a>
  <a href="https://github.com/prscX/vs-essential-plugins/pulls"><img alt="PRs Welcome" src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg" /></a>
  <a href="https://github.com/prscX/vs-essential-plugins#License"><img src="https://img.shields.io/npm/l/vs-essential-plugins.svg?style=flat" /></a>
</p>

    Visual Studio Code - Essential Plugins

If this project has helped you out, please support us with a star 🌟

</h1>

[VS Code](https://code.visualstudio.com/) is a new type of tool that combines the simplicity of a code editor with what developers need for their core edit-build-debug cycle. Code provides comprehensive editing and debugging support, an extensibility model, and lightweight integration with existing tools.

This library enhances usability by providing prepackaged essential plugins for visual studio code. Before we dive into on how to use this library. We would like to thank all the contributor of plugins we have configured in this library

> **Note:** These prepacked plugins will definitely help developers of [React](https://github.com/facebook/react) & [ReactNative](https://github.com/facebook/react-native) community

## 💻 Usage

`npm install vs-essential-plugins --save`

`npm install`

On `install` it will automatically install all plugins configured in library

> **Note:**
>
> - If you are using MAC then please make your that you have install `code` command in PATH. Please refer [Microsoft Blog](https://code.visualstudio.com/docs/setup/mac#_launching-from-the-command-line) for more details
> - All plugins are defined in package.json `postinstall` section

# Essential Plugins

- [svetlozarangelov.vscode-open-project](https://marketplace.visualstudio.com/items?itemName=svetlozarangelov.vscode-open-project): _This extension allows you to easily switch projects inside Visual Studio Code_
- [DavidAnson.vscode-markdownlint](https://marketplace.visualstudio.com/items?itemName=DavidAnson.vscode-markdownlint): _Markdown/CommonMark linting and style checking for Visual Studio Code_
- [dbaeumer.vscode-eslint](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint): _The extension uses the ESLint library installed in the opened workspace folder_
- [vsmobile.vscode-react-native](https://marketplace.visualstudio.com/items?itemName=vsmobile.vscode-react-native): _This extension provides a development environment for React Native projects. Using this extension, you can debug your code, quickly run react-native commands from the command palette, and use IntelliSense to browse objects, functions and parameters for React Native APIs_
- [flowtype.flow-for-vscode](https://marketplace.visualstudio.com/items?itemName=flowtype.flow-for-vscode): _This extension adds Flow support for VS Code. Flow is a static type checker, designed to find type errors in JavaScript programs_
- [gcazaciuc.vscode-flow-ide](https://marketplace.visualstudio.com/items?itemName=gcazaciuc.vscode-flow-ide): _An alternative Flowtype extension for Visual Studio Code. Flowtype is a static type checker ment to find errors in Javascript programs_
- [streetsidesoftware.code-spell-checker](https://marketplace.visualstudio.com/items?itemName=streetsidesoftware.code-spell-checker): _A basic spell checker that works well with camelCase code_
- [ms-vscode.atom-keybindings](https://marketplace.visualstudio.com/items?itemName=ms-vscode.atom-keybindings): _This extension ports popular Atom keyboard shortcuts to Visual Studio Code. After installing the extension and restarting VS Code your favorite keyboard shortcuts from Atom are now available_
- [robertohuertasm.vscode-icons](https://marketplace.visualstudio.com/items?itemName=robertohuertasm.vscode-icons): _Bring icons to your Visual Studio Code_
- [naumovs.color-highlight](https://marketplace.visualstudio.com/items?itemName=naumovs.color-highlight): _This extension styles css/web colors found in your document_
- [2gua.rainbow-brackets](https://marketplace.visualstudio.com/items?itemName=2gua.rainbow-brackets): _Provide rainbow colors for the round brackets, the square brackets and the squiggly brackets. This is particularly useful for Lisp or Clojure programmers, and of course, JavaScript, and other programmers_
- [wayou.vscode-todo-highlight](https://marketplace.visualstudio.com/items?itemName=wayou.vscode-todo-highlight): _Highlight TODO,FIXME or any annotations within your code_
- [SirTori.indenticator](https://marketplace.visualstudio.com/items?itemName=SirTori.indenticator): _Visually highlights the current indent depth_
- [cssho.vscode-svgviewer](https://marketplace.visualstudio.com/items?itemName=cssho.vscode-svgviewer): _SVG Viewer for Visual Studio Code Visual Studio Marketplace_
- [formulahendry.auto-close-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-close-tag): _Automatically add HTML/XML close tag, same as Visual Studio IDE or Sublime Text does_
- [formulahendry.auto-rename-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-rename-tag): _Automatically rename paired HTML/XML tag, same as Visual Studio IDE does_
- [formulahendry.auto-complete-tag](https://marketplace.visualstudio.com/items?itemName=formulahendry.auto-complete-tag): _Combine the functions of Auto Close Tag and Auto Rename Tag_
- [christian-kohler.path-intellisense](https://marketplace.visualstudio.com/items?itemName=christian-kohler.path-intellisense): _Visual Studio Code plugin that autocompletes filenames_
- [EQuimper.react-native-react-redux](https://marketplace.visualstudio.com/items?itemName=EQuimper.react-native-react-redux): _React-Native/React/Redux snippets for es6/es7_
- [alexdima.copy-relative-path](https://marketplace.visualstudio.com/items?itemName=alexdima.copy-relative-path): _Copy Relative Path_
- [DotJoshJohnson.xml](https://marketplace.visualstudio.com/items?itemName=DotJoshJohnson.xml): _XML Tools for Visual Studio Code_
- [formulahendry.code-runner](https://marketplace.visualstudio.com/items?itemName=formulahendry.code-runner): _Run code snippet or code file for multiple languages: C, C++, Java, JavaScript, PHP, Python, Perl, Ruby, Go, Lua, Groovy, PowerShell, BAT/CMD, BASH/SH, F# Script, F# (.NET Core), C# Script, C# (.NET Core), VBScript, TypeScript, CoffeeScript, Scala, Swift, Julia, Crystal, OCaml Script, R, AppleScript, Elixir, Visual Basic .NET, Clojure, Haxe, Objective-C, Rust, Racket, AutoHotkey, AutoIt, Kotlin, Dart, Free Pascal, Haskell, Nim, D, and custom command_
- [joelday.docthis](https://marketplace.visualstudio.com/items?itemName=joelday.docthis): _"Document This" is a Visual Studio Code extension that automatically generates detailed JSDoc comments for both TypeScript and JavaScript files_
- [waderyan.gitblame](https://marketplace.visualstudio.com/items?itemName=waderyan.gitblame): _See Git Blame information in the status bar for the currently selected line_
- [eamodio.gitlens](https://marketplace.visualstudio.com/items?itemName=eamodio.gitlens): _GitLens supercharges the built-in Visual Studio Code Git capabilities. It helps you to visualize code authorship at a glance via Git blame annotations and code lens, seamlessly navigate and explore the history of a file or branch, gain valuable insights via powerful comparison commands, and so much more_
- [xyz.local-history](https://marketplace.visualstudio.com/items?itemName=xyz.local-history): _A visual source code plugin for maintaining local history of files_
- [esbenp.prettier-vscode](https://marketplace.visualstudio.com/items?itemName=esbenp.prettier-vscode): _Prettier formatter for Visual Studio Code_
- [Orta.vscode-react-native-storybooks](https://marketplace.visualstudio.com/items?itemName=Orta.vscode-react-native-storybooks): _Select storybooks inside your editor_
- [IBM.output-colorizer](https://marketplace.visualstudio.com/items?itemName=IBM.output-colorizer): _Language extension for VSCode/Bluemix Code that adds syntax colorization for both the output/debug/extensions panel and \*.log files_
- [qezhu.gitlink](https://marketplace.visualstudio.com/items?itemName=qezhu.gitlink): _Inspired by GitHub extension for Visual Studio, this extension provide the feature that Go To current file's online link in browser and Copy the link in clipboard_

## ✨ Credits

## 🤔 How to contribute

Have an idea? Found a bug? Please raise to [ISSUES](https://github.com/prscX/vs-essential-plugins/issues).
Contributions are welcome and are greatly appreciated! Every little bit helps, and credit will always be given.

## 💫 Where is this library used?

If you are using this library in one of your projects, add it in this list below. ✨

## 📜 License

This library is provided under the Apache 2 License.

vs-essential-plugins @ [prscX](https://github.com/prscX)

## 💖 Support my projects

I open-source almost everything I can, and I try to reply everyone needing help using these projects. Obviously, this takes time. You can integrate and use these projects in your applications for free! You can even change the source code and redistribute (even resell it).

However, if you get some profit from this or just want to encourage me to continue creating stuff, there are few ways you can do it:

- Starring and sharing the projects you like 🚀
- If you're feeling especially charitable, please follow [prscX](https://github.com/prscX) on GitHub.

  <a href="https://www.buymeacoffee.com/prscX" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

  Thanks! ❤️
  <br/>
  [prscX.github.io](https://prscx.github.io)
  <br/>
  </ Pranav >
